##### 简要描述

- 该接口用于根据停车订单，查询当前的停车费用

##### 请求URL
- ` http://localhost:8888/Api/V2/OpenApi/GetOrderPrice `
  
##### 请求方式
- GET 

##### 请求类型
- Content-Type：application/json 

##### 请求参数
| 参数           | 类型               | 参数名         | 是否必填 | 描述       | 说明                                     |
| -------------- | ------------------ | -------------- | -------- | ------------------------------------------- |------------------ |
| ParkKey|body|string| yes | 停车场编号|本地停车场编号|
| AppId|body|string| yes | 应用服务标识|本地停车场应用服务标识|
| TimeStamp|body|string| yes | 时间戳|时间戳13位，精确到毫秒|
| Nonce|body|string| yes | 随机字符串|随机字符串|
| Sign|body|string| yes | 接口签名|按照接口鉴权生成的签名|
| Data|body|object| yes | 具体数据|对应接口发送的数据对象|
|» OrderNo|body|string| yes | 要查询的停车订单|要查询的停车订单|
|» LicensePlateNumber|body|string| no | 车牌号码|车牌号码|
|» PlateCouponNo|body|string| no | 优惠券编码|优惠券编码|

##### 请求示例

```
{
    "ParkKey": "{{parkkey}}",
    "AppId": "{{appid}}",
    "TimeStamp": "{{timestamp}}",
    "Nonce": "dvblcecapqdw",
    "Sign": "bgxgleocfosiigzerubivpsu",
    "Data": {
        "orderNo": "20240321100533618-WX1243无牌"
    }
}
```

##### 返回参数说明
| 参数           | 类型               | 参数名         | 是否必填 | 描述       | 说明                                     |
| -------------- | ------------------ | -------------- | -------- | ------------------------------------------- |------------------ |
| ResultCode|integer|true|none|请求结果代码|详细信息请查看类型枚举/请求结果代码枚举，默认200为操作成功|
| ResultMsg|string|true|none|请求提示信息|接口请求返回的信息提示|
| ResultId|string|true|none|请求响应结果标识|每一次进行接口请求时，响应本次处理的标识|
| Data|object¦null|false|none|具体数据|对应接口响应的数据对象|
|» OrderNo|string¦null|true|none|停车订单|车辆入场时创建的唯一停车订单|
|» CouponSchemeNos|[string]|true|none|已经使用的优惠劵编号集合|已经使用的优惠劵编号集合|
|» LicensePlateNumber|number|true|none|车牌号|车牌号|
|» EntryTime|string|true|none|入场时间|入场时间|
|» CalcTime|string|true|none|计费时间|计费时间|
|» TotalAmountDue|string|true|none|总应收|总应收|
|» TotalAmountPaid|string|true|none|总实收|总实收|
|» DiscountAmount|string|true|none|折扣金额|折扣金额|
|» CalcDetail|string|true|none|计费详情|计费详情|
|»» AreaNo|string|true|none|区域编码|区域编码|
|»» AreaName|string|true|none|区域名称|区域名称|
|»» StartTime|string|true|none|开始时间|开始时间|
|»» EndTime|string|true|none|结束时间|结束时间|
|»» CalcAmount|string|true|none|计费金额|计费金额|
|»» FreeMinutes|string|true|none|免费分钟|免费分钟|
|»» StayMinutes|string|true|none|停车时长|停车时长|
|»» Remarks|string|true|none|备注|备注|
|»» IsOverTime|string|true|none|是否超时|是否超时|
|»» IsCarExpire|string|true|none|是否过期|是否过期|

##### 返回示例

```
{
    "ResultCode": 200,
    "ResultMsg": "获取指定停车订单的停车费用信息成功！",
    "ResultId": "1770646886669123584",
    "Data": {
        "OrderNo": "20240321100533618-WX1243无牌",
        "LicensePlateNumber": "WX1243无牌",
        "EntryTime": "2024-03-21 10:05:33",
        "CalcTime": "2024-03-21 11:01:29",
        "TotalAmountDue": 1.0,
        "TotalAmountPaid": 1.0,
        "DiscountAmount": 0.0,
        "CalcDetail": [
            {
                "AreaNo": "1710501508796427",
                "AreaName": "外场",
                "StartTime": "2024-03-21 10:05:33",
                "EndTime": "2024-03-21 11:01:29",
                "CalcAmount": 1.0,
                "DiscountAmount": null,
                "FreeMinutes": 0,
                "StayMinutes": 56,
                "Remarks": "按 临时车A 收费",
                "IsOverTime": 0,
                "IsCarExpire": 0
            }
        ],
        "PlateCouponNos": []
    }
}
```