##### 简要描述

- 该接口用于实现管理新增、更新、删除月租车记录
- 注意：在停车场系统中车主名下的车共享同一个开始时间和结束时间，并且只能发布一种月租车类型；如果当初新增或更新操作时，同一个车主传入了多个车辆信息，最终按照结束时间排序，结束时间最大的数据作为参考数据更新到数据库！


	注：当前版本，固定车，默认授权全部区域，暂无接口可更改
##### 请求URL
- ` http://localhost:8888/Api/V2/OpenApi/Notice `
  
##### 请求方式
- POST 

##### 请求类型
- Content-Type：application/json 

##### 请求参数

------------

**Query参数**

| 参数名  | 类型  | 示例值  | 说明  |
| ------------ | ------------ | ------------ |------------ |
| Route  | string  | MonthlyCar  |接口路由|

**Body参数**

| 参数           | 类型               | 参数名         | 是否必填 | 描述         | 说明                                   |
| -------------- | ------------------ | -------------- | -------- | ------------------------------------------- |------------------ |
| ParkKey|body|string| yes | 停车场编号|本地停车场编号|
| AppId|body|string| yes | 应用服务标识|本地停车场应用服务标识|
| TimeStamp|body|string| yes | 时间戳|时间戳13位，精确到毫秒|
| Nonce|body|string| yes | 随机字符串|随机字符串|
| Sign|body|string| yes | 接口签名|按照接口鉴权生成的签名|
| Data|body|object¦null| yes | 具体数据|对应接口响应的数据对象|
|» NoticeType|body|integer| yes | 通知类型|通知类型：0.新增或更新 1.删除|
|» Items|body|[object]| yes | 通知数据集合|通知数据集合|
|»» No|body|string| yes | 记录编号|表示当前记录的编号，唯一值|
|»» LicensePlateNumber|body|string¦null| yes | 车牌号码|车牌号码，注意，车牌号码入参时，默认都转换成大写|
|»» ParkingSpotNumber|body|string¦null| yes | 车场车位号|车场车位号|
|»» OwnerParkingSpaceCount|body|integer| yes | 车主车位数|车主车位数|
|»» OwnerName|body|string¦null| yes | 车主名称|发行车辆记录的车主名称|
|»» OwnerNo|body|string¦null| yes | 车主编号|记录车主的唯一标识编号|
|»» OwnerIDCard|body|string¦null| yes | 车主身份证信息|车主身份证信息|
|»» OwnerLicense|body|string¦null| yes | 车主驾驶证|车主驾驶证|
|»» OwnerAddress|body|string| yes | 车主住址|车主居住地址|
|»» PhoneNumber|body|string| yes | 手机号码|手机号码|
|»» Email|body|string¦null| yes | 邮箱地址|邮箱地址|
|»» StartTime|body|string¦null| yes | 开始时间|开始时间，参考基本规则中的日期格式，精确到秒，如：2023-08-01 09:34:51|
|»» EndTime|body|string¦null| yes | 结束时间|结束时间，参考基本规则中的日期格式，精确到秒，如：2023-08-01 09:34:51|
|»» StoredVehicleBalance|body|number| yes | 储值车余额|储值车余额，单位元，精确到后两位小数点|
|»» VehicleTypeNo|body|string¦null| yes | 车辆类型编号|车辆类型编号|
|»» ParkingCardTypeNo|body|string¦null| yes | 车牌类型编号|车牌类型编号|
|»» OperatorName|body|string¦null| yes | 操作人姓名|操作人姓名|
|»» Remarks|body|string¦null| yes | 备注信息|备注信息|
|»» EnableOffline|body|integer| yes | 白名单使能|相机离线自动开闸(白名单)：0-禁用，1-启用|
|»» IsDeleteOwner|body|boolean| yes | 是否删除车主信息|当执行删除操作时，是否一起删除车主信息，注意删除车主信息时，车主关联的车辆信息将一并被删除|

##### 请求示例
```
{
    "ParkKey": "{{parkkey}}",
    "AppId": "{{appid}}",
    "TimeStamp": "{{timestamp}}",
    "Nonce": "dvrscrdgxrob",
    "Sign": "xicygpfwjipwbbnjysopoklv",
    "Data": {
        "NoticeType": 0,
        "Items": [
            {
                "No": "630000201108254378",
                "LicensePlateNumber": "粤P12345",
                "ParkingSpotNumber": "56",
                "OwnerParkingSpaceCount": 2,
                "OwnerName": "ces",
                "OwnerNo": "410000199701311192",
                "OwnerIDCard": "82",
                "OwnerLicense": "测试",
                "OwnerAddress": "山",
                "PhoneNumber": "18100000009",
                "Email": "b.ypwwtiqst@qq.com",
                "StartTime": "2024-02-27 11:04:31",
                "EndTime": "2024-02-27 11:04:31",
                "StoredVehicleBalance": 101.88646804833,
                "VehicleTypeNo": "1708773681734708",
                "ParkingCardTypeNo": "1708773681731399",
                "OperatorName": "管理员",
                "Remarks": "这是一个显眼的备注信息",
                "EnableOffline": 1,
                "IsDeleteOwner": false
            }
        ]
    }
}
```
##### 返回参数说明
| 参数           | 类型               | 参数名         | 是否必填 | 描述       | 说明                                     |
| -------------- | ------------------ | -------------- | -------- | ------------------------------------------- |------------------ |
| ResultCode|integer|true|none|请求结果代码|详细信息请查看类型枚举/请求结果代码枚举，默认200为操作成功|
| ResultMsg|string|true|none|请求提示信息|接口请求返回的信息提示|
| ResultId|string|true|none|请求响应结果标识|每一次进行接口请求时，响应本次处理的标识|
| Data|object¦null|false|none|具体数据|对应接口响应的数据对象|

##### 返回示例

```
{
    "ResultCode": 200,
    "ResultMsg": "本次新增或更新操作成功！",
    "ResultId": "1762312991271845888"
}
```