##### 简要描述

- 第三方停车业务接收车辆出场回调通知接口定义规范
- 如果未实现该接口，请不要在设置回调参数中启用该接口，避免无意义的数据通知操作！

##### 示例URL

- ` {{第三方URL}}，示例URL：http://localhost:8888/API/V2/OnVehicleOut `

	
	注：此处url指的是软件回调给第三方的URL，即第三方要接收软件上传数据的地址；
	
##### 请求方式
- POST 

##### 请求类型
- Content-Type：application/json 

##### 回调参数说明

------------
| 参数           | 类型               | 参数名         | 是否必填 | 描述       | 说明                                     |
| -------------- | ------------------ | -------------- | -------- | ------------------------------------------- |------------------ |
| ParkKey|body|string| yes | 停车场编号|本地停车场编号|
| AppId|body|string| yes | 应用服务标识|本地停车场应用服务标识|
| TimeStamp|body|string| yes | 时间戳|时间戳13位，精确到毫秒|
| Nonce|body|string| yes | 随机字符串|随机字符串|
| Sign|body|string| yes | 接口签名|按照接口鉴权生成的签名|
| Data|body|object| yes | 具体数据|对应接口发送的数据对象|
|» OrderNo|body|string¦null| yes | 停车订单|车辆入场时创建的唯一停车订单|
|» LicensePlateNumber|body|string¦null| yes | 车牌号码|车牌号码，注意，车牌号码入参时，默认都转换成大写|
|» ExitTime|body|string¦null| yes | 出场时间|出场时间，参考基本规则中的日期格式，精确到秒，如：2023-08-01 09:34:51|
|» LicensePlateColor|body|integer| yes | 车牌颜色序号|详细信息参考枚举类型/车牌颜色枚举中的序号|
|» ExitLaneNo|body|string¦null| yes | 出场车道编号|出场车道编号|
|» ExitLaneName|body|string¦null| yes | 出场车道名称|出场车道名称|
|» ExitOperatorName|body|string¦null| yes | 出场操作员|出场操作员|
|» VehicleTypeNo|body|string¦null| yes | 车辆类型编号|车辆类型编号|
|» VehicleTypeName|body|string¦null| yes | 车辆类型名称|车辆类型名称|
|» ParkingCardTypeNo|body|string¦null| yes | 车牌类型编号|车牌类型编号|
|» ParkingCardTypeName|body|string¦null| yes | 车牌类型名称|车牌类型名称|
|» ParkingAreaNo|body|string| yes | 停车区域编号|当前停车区域编号|
|» ParkingAreaName|body|string¦null| yes | 停车区域名称|当前停车区域名称|
|» ExitImageUrl|body|string¦null| yes | 出场通行抓拍图片地址|出场通行抓拍图片地址，如果启用了云平台并启用了图片存储功能，则这个是一个云端存储图片的地址|
|» ExitImageBase64|body|string¦null| yes | 出场通行抓拍图片|出场通行抓拍图片Base64|
|» TotalAmountDue|body|number| yes | 应支付总金额|应支付总金额，单位元，精确到后两位小数点|
|» TotalAmountPaid|body|number| yes | 实收总金额 |实收总金额  ，单位元，精确到后两位小数点|
|» IsFreePass|body|boolean| yes | 是否免费放行|是否免费放行|
|» FreePassReason|body|string¦null| yes | 免费放行原因|车辆免费放行时，填写的免费放行原因|
|» Remarks|body|string¦null| yes | 备注信息|备注信息|

##### 回调参数示例
```
{
	"ParkKey":"1708773681705596",
	"AppId":"p226uwb3",
	"TimeStamp":"1709015628109",
	"Data":{
		"OrderNo":"1708978481390181-EEE666",
		"LicensePlateNumber":"粤EEE666",
		"ExitTime":"2024-02-27 14:33:41",
		"LicensePlateColor":1,
		"ExitLaneNo":"2",
		"ExitLaneName":"出口车道",
		"ExitOperatorName":"超级管理员",
		"VehicleTypeNo":"1708773681734708",
		"VehicleTypeName":"蓝牌车",
		"ParkingCardTypeNo":"1708773681731663",
		"ParkingCardTypeName":"临时车A",
		"ParkingAreaNo":"1708773681832919",
		"ParkingAreaName":"外场",
		"ExitImageUrl":null,
		"ExitImageBase64":null,
		"TotalAmountDue":2.00,
		"TotalAmountPaid":2.00,
		"IsFreePass":false,
		"FreePassReason":null,
		"Remarks":null
		},
	"Nonce":"1762365395497418752",
	"Sign":"xiryg2kcliblcm+noqvzxzqxas5yeunytxraov8wkmm="
}

```

##### 回调返回说明
| 参数               | 类型                | 参数名               | 是否必填 | 描述                                                         |
| ------------------ | ------------------- | -------------------- | -------- | ------------------------------------------------------------ |
| ResultCode|integer|true|none|请求结果代码|详细信息请查看类型枚举/请求结果代码枚举，默认200为操作成功|
| ResultMsg|string|true|none|请求提示信息|接口请求返回的信息提示|
| Data|object¦null|false|none|具体数据|对应接口响应的数据对象|

##### 返回示例

```
{
  "ResultCode": 200,
  "ResultMsg": "操作成功"
}
```