##### 简要描述

- 第三方停车业务接收缴费结果回调通知接口定义规范
- 如果未实现该接口，请不要在设置回调参数中启用该接口，避免无意义的数据通知操作！

##### 示例URL

- ` {{第三方URL}}，示例URL：http://localhost:8888/API/V2/OnPayResult `

	
	注：此处url指的是软件回调给第三方的URL，即第三方要接收软件上传数据的地址；

##### 请求方式
- POST 

##### 请求类型
- Content-Type：application/json 

##### 回调参数说明

------------
| 参数           | 类型               | 参数名         | 是否必填 | 描述       | 说明                                     |
| -------------- | ------------------ | -------------- | -------- | ------------------------------------------- |------------------ |
| ParkKey|body|string| yes | 停车场编号|本地停车场编号|
| AppId|body|string| yes | 应用服务标识|本地停车场应用服务标识|
| TimeStamp|body|string| yes | 时间戳|时间戳13位，精确到毫秒|
| Nonce|body|string| yes | 随机字符串|随机字符串|
| Sign|body|string| yes | 接口签名|按照接口鉴权生成的签名|
| Data|body|object| yes | 具体数据|对应接口发送的数据对象|
|» OrderNo|body|string¦null| yes | 停车订单|车辆入场时创建的唯一停车订单|
|» PaymentOrderNo|body|string| yes | 支付订单编号|支付订单编号|
|» LicensePlateNumber|body|string¦null| yes | 车牌号码|车牌号码，注意，车牌号码入参时，默认都转换成大写|
|» TotalAmountDue|body|number| yes | 应支付总金额|应支付总金额，单位元，精确到后两位小数点|
|» TotalAmountPaid|body|number| yes | 实收总金额 |实收总金额  ，单位元，精确到后两位小数点|
|» DiscountAmount|body|number| yes | 优惠金额 |优惠金额  ，单位元，精确到后两位小数点|
|» PaymentTime|body|string| yes | 支付时间|支付时间，参考基本规则中的日期格式，精确到秒，如：2023-08-01 09:34:51|
|» PaymentMethod|body|string| yes | 支付方式编号|详细请看类型枚举/支付方式枚举信息|
|» PayScene|body|integer| yes | 支付场景|详细请看类型枚举/支付场景枚举信息|
|» VehicleTypeNo|body|string¦null| yes | 车辆类型编号|车辆类型编号|
|» VehicleTypeName|body|string¦null| yes | 车辆类型名称|车辆类型名称|
|» ParkingCardTypeNo|body|string¦null| yes | 车牌类型编号|车牌类型编号|
|» ParkingCardTypeName|body|string¦null| yes | 车牌类型名称|车牌类型名称|
|» Remarks|body|string¦null| yes | 备注信息|备注信息|
|» ParkingDuration|body|integer| yes | 停车时长|停车时长，单位分钟|
|» StoredValueDeduction|body|number| no | 储值车抵扣金额|储值车抵扣金额，单位元，精确到后两位小数点|
|» OperatorName|body|string¦null| yes | 操作人姓名|操作人姓名|
|» CouponUsageList|body|[object]| no | 优惠卷使用列表|包含当前订单使用了优惠卷的编号集合列表|
|»» No|body|string| yes ||已使用的优惠券编号|

##### 回调参数示例
```
{
	"ParkKey":"1710146133740403",
	"AppId":"oouon027",
	"TimeStamp":"1710139306676",
	"Data":{
		"OrderNo":"1710146381449750-JVHR0B",
		"PaymentOrderNo":"PO1710168078491471",
		"LicensePlateNumber":"藏JVHR0B",
		"TotalAmountDue":1.00,
		"TotalAmountPaid":1.00,
		"DiscountAmount":0.00,
		"PaymentTime":"2024-03-11 14:41:18",
		"PaymentMethod":"79001",
		"PayScene":0,
		"VehicleTypeNo":"1710146133767408",
		"VehicleTypeName":"蓝牌车",
		"ParkingCardTypeNo":"1710146133764257",
		"ParkingCardTypeName":"临时车A",
		"Remarks":null,
		"ParkingDuration":361,
		"StoredValueDeduction":0.00,
		"OperatorName":"超级管理员",
		"CouponUsageList":null
		},
	"Nonce":"1767078445005701120",
	"Sign":"jppxfrewamzt5ieb7jz1fthtqqn408xtudilh3h633k="
}
```

##### 回调返回说明
| 参数               | 类型                | 参数名               | 是否必填 | 描述                                                         |
| ------------------ | ------------------- | -------------------- | -------- | ------------------------------------------------------------ |
| ResultCode|integer|true|none|请求结果代码|详细信息请查看类型枚举/请求结果代码枚举，默认200为操作成功|
| ResultMsg|string|true|none|请求提示信息|接口请求返回的信息提示|
| Data|object¦null|false|none|具体数据|对应接口响应的数据对象|

##### 返回示例

```
{
  "ResultCode": 200,
  "ResultMsg": "操作成功"
}
```