##### 简要描述

- 第三方停车业务接收异常通行信息变动回调通知接口定义规范
- 如果未实现该接口，请不要在设置回调参数中启用该接口，避免无意义的数据通知操作！

##### 示例URL

- ` {{第三方URL}}，示例URL：http://localhost:8888/API/V2/OnAbnormalPass `

	
	注：此处url指的是软件回调给第三方的URL，即第三方要接收软件上传数据的地址；

##### 请求方式
- POST 

##### 请求类型
- Content-Type：application/json 

##### 回调参数说明

------------
| 参数           | 类型               | 参数名         | 是否必填 | 描述       | 说明                                     |
| -------------- | ------------------ | -------------- | -------- | ------------------------------------------- |------------------ |
| ParkKey|body|string| yes | 停车场编号|本地停车场编号|
| AppId|body|string| yes | 应用服务标识|本地停车场应用服务标识|
| TimeStamp|body|string| yes | 时间戳|时间戳13位，精确到毫秒|
| Nonce|body|string| yes | 随机字符串|随机字符串|
| Sign|body|string| yes | 接口签名|按照接口鉴权生成的签名|
| Data|body|object| yes | 具体数据|对应接口发送的数据对象|
|» No|body|string| yes | 记录编号|表示当前记录的编号，唯一值|
|» OrderNo|body|string¦null| yes | 停车订单|异常通行时，如果是无入场记录自动出场则会创建停车订单，这里表示创建的停车订单号|
|» LicensePlateNumber|body|string¦null| yes | 车牌号码|车牌号码，注意，车牌号码入参时，默认都转换成大写   |
|» PassageTime|body|string| yes | 通行时间|通行时间，参考基本规则中的日期格式，精确到秒，如：2023-08-01 09:34:51|
|» Remarks|body|string¦null| yes | 备注信息|备注信息|
|» ImageBase64|body|string| yes | 图片Base64|这里表示通行时抓拍的图片Base64数据，不参与签名|
|» InOutType|body|integer| yes | 车道的进出场类型|车道的进出场类型 0-表示出场 1-表示入场|
|» PassageLaneNo|body|string| yes | 通行车道编号|通行车道编号|
|» PassageLaneName|body|string| yes | 通行车道名称|通行车道名称|
|» OperatorName|body|string¦null| yes | 操作人姓名|操作人姓名|
|» AbnormalPassType|body|integer| yes | 异常通行类型|异常通行类型：6101-无入场记录自动放行，6201-人工开闸，6202-人工关闸，6211-道闸常开，6212-取消道闸常开|

##### 回调参数示例
```
{
	"ParkKey":"1708773681705596",
	"AppId":"p226uwb3",
	"TimeStamp":"1709018037090",
	"Data":{
		"No":"1709046823138325",
		"OrderNo":null,
		"LicensePlateNumber":null,
		"PassageTime":"2024-02-27 15:13:39",
		"Remarks":"[出口相机]开闸成功！",
		"ImageBase64":null,
		"InOutType":0,
		"PassageLaneNo":"2",
		"PassageLaneName":"出口车道",
		"OperatorName":"admin",
		"AbnormalPassType":6200
		},
	"Nonce":"1762375499496062976",
	"Sign":"glbo72hyooartypvwcdct8obxkrxayjlkxvxcmtj2/8="
}
```

##### 回调返回说明
| 参数               | 类型                | 参数名               | 是否必填 | 描述                                                         |
| ------------------ | ------------------- | -------------------- | -------- | ------------------------------------------------------------ |
| ResultCode|integer|true|none|请求结果代码|详细信息请查看类型枚举/请求结果代码枚举，默认200为操作成功|
| ResultMsg|string|true|none|请求提示信息|接口请求返回的信息提示|
| Data|object¦null|false|none|具体数据|对应接口响应的数据对象|

##### 返回示例

```
{
  "ResultCode": 200,
  "ResultMsg": "操作成功"
}
```