##### 简要描述

- 第三方停车业务接收岗亭车道信息变动的回调通知接口定义规范
- 当某个岗亭的车道信息变更时，回到所有车道信息到第三方停车业务
- 如果未实现该接口，请不要在设置回调参数中启用该接口，避免无意义的数据通知操作！

##### 示例URL

- ` {{第三方URL}}，示例URL：http://localhost:8888/API/V2/OnUnsubscribedVehicle `

	
	注：此处url指的是软件回调给第三方的URL，即第三方要接收软件上传数据的地址；

##### 请求方式
- POST 

##### 请求类型
- Content-Type：application/json 

##### 回调参数说明

------------
| 参数           | 类型               | 参数名         | 是否必填 | 描述       | 说明                                     |
| -------------- | ------------------ | -------------- | -------- | ------------------------------------------- |------------------ |
| ParkKey|body|string| yes | 停车场编号|本地停车场编号|
| AppId|body|string| yes | 应用服务标识|本地停车场应用服务标识|
| TimeStamp|body|string| yes | 时间戳|时间戳13位，精确到毫秒|
| Nonce|body|string| yes | 随机字符串|随机字符串|
| Sign|body|string| yes | 接口签名|按照接口鉴权生成的签名|
| Data|body|object| yes | 具体数据|对应接口发送的数据对象|
|» SentryHostNo|body|string| yes | 岗亭编号|岗亭编号|
|» Lanes|body|[object]| yes | 岗亭的车道信息|岗亭的车道信息|
|»» Uid|body|integer| yes | 记录唯一主键|当前记录唯一主键|
|»» No|body|string| yes | 记录编号|表示当前记录的编号，唯一值|
|»» LaneName|body|string¦null| yes | 车道名称|车道名称|
|»» LaneType|body|integer| yes | 车道类型|车道类型，1-汽车通道 2-非机动车道(人行通道)|
|»» LaneDutyMode|body|integer| yes | 车道值守类型|车道值守类型， 0-无人值守车道 1-现场值守|
|»» CameraMode|body|integer| yes | 相机模式|相机模式：1-单相机模式，2-双相机模式，3-多相机模式|
|»» IdInterval|body|integer| yes | 相机识别间隔|识别间隔(秒)([双相机模式，多相机模式]生效)|
|»» IsBackCar|body|integer¦null| yes | 是否启用倒车|是否启用倒车，0-禁用，1-启用|
|»» IsCharge|body|integer| yes | 车道启用收费|车道是否启用收费，0-禁用，1-启用|
|»» CreationTime|body|string| yes | 创建时间|创建数据的时间|
|»» IsSense|body|integer| yes | 无牌车扫码是否启用地感判断|无牌车扫码是否启用地感判断，0-不启用，1-启用|
|»» IsSameInOut|body|integer| yes | 是否同进同出模式|是否同进同出模式，0-不是 1-是|
|»» SameInOutLaneNo|body|string¦null| yes | 同进同出时关联的车道编号|同进同出时关联的车道编号|
|»» SameInOutType|body|integer| yes | 同进同出时车道的进出口类型|同进同出时车道的进出口类型，0-入口类型 1-出口类型|
|»» IsEnableBoard|body|integer| yes | 是否启用车道控制板|是否启用车道控制板， 0-不启用 1-启用|
|»» LaneLinkAreas|body|[object]| yes | 当前车道绑定的区域信息|当前车道绑定的区域信息|
|»»» No|body|string| yes | 记录编号|表示当前记录的编号，唯一值|
|»»» AreaNo|body|string| yes | 关联区域的编号|关联区域的编号|
|»»» InOutMode|body|integer| yes | 车道在当前区域的进出口模式|车道在当前区域的进出口模式，0-出口车道 1-入口车道|

##### 回调参数示例
```
{
	"ParkKey":"1709368233332675",
	"AppId":"0uy5t2d6",
	"TimeStamp":"1709339796001",
	"Data":
		{
			"SentryHostNo":"1709368233332794",
			"Lanes":[{
					"SentryHostNo":null,
					"Uid":1,
					"No":"1",
					"LaneName":"入口车道",
					"LaneType":1,
					"LaneDutyMode":1,
					"CameraMode":1,
					"IdInterval":3,
					"IsBackCar":0,
					"IsCharge":0,
					"CreationTime":"2024-03-02 08:30:33",
					"IsSense":1,
					"IsSameInOut":0,
					"SameInOutLaneNo":null,
					"SameInOutType":0,
					"IsEnableBoard":0,
					"LaneLinkAreas":
						[{
						"No":"1709368233450816",
						"AreaNo":"1709368233449162",
						"InOutMode":1
						}]
				},
				{
					"SentryHostNo":null,
					"Uid":2,
					"No":"2",
					"LaneName":"出口车道",
					"LaneType":1,
					"LaneDutyMode":1,
					"CameraMode":1,
					"IdInterval":2,
					"IsBackCar":0,
					"IsCharge":1,
					"CreationTime":"2024-03-02 08:30:33",
					"IsSense":1,
					"IsSameInOut":0,
					"SameInOutLaneNo":"",
					"SameInOutType":0,
					"IsEnableBoard":0,
					"LaneLinkAreas":
						[{
							"No":"1709368586544601",
							"AreaNo":"1709368233449162",
							"InOutMode":0
						}]
					}
				]},
	"Nonce":"1763725054183505920",
	"Sign":"cnvyoh5oglf+zngz6m4dybxvww3r/dgnhgawwfi2hcu="
}
```

##### 回调返回说明
| 参数               | 类型                | 参数名               | 是否必填 | 描述                                                         |
| ------------------ | ------------------- | -------------------- | -------- | ------------------------------------------------------------ |
| ResultCode|integer|true|none|请求结果代码|详细信息请查看类型枚举/请求结果代码枚举，默认200为操作成功|
| ResultMsg|string|true|none|请求提示信息|接口请求返回的信息提示|
| Data|object¦null|false|none|具体数据|对应接口响应的数据对象|

##### 返回示例

```
{
  "ResultCode": 200,
  "ResultMsg": "操作成功"
}
```